|
|||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | ||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | ||||||||
java.lang.Objectjava.util.AbstractCollection
java.util.AbstractList
java.util.ArrayList
step10.type.T
step10.type.ProcT
public static class type.ProcT
base class for procedures,
itself used to represent a mini.yyTree.Proc.
No descendants if used to represent a type.
| Field Summary | |
|---|---|
protected String[] |
names
parameter names, null in derived classes and in type. |
protected type.T[] |
params
parameter types, null in derived classes, possibly empty. |
protected type.T |
result
result type, null in derived classes. |
| Fields inherited from class step10.type.T |
|---|
map, type |
| Fields inherited from class java.util.AbstractList |
|---|
modCount |
| Constructor Summary | |
|---|---|
protected |
type.ProcT(Object type,
List sub)
|
protected |
type.ProcT(type.T result,
String name,
type.T[] params,
String[] names,
List body)
|
protected |
type.ProcT(type.T result,
type.T[] params)
|
| Method Summary | |
|---|---|
String |
asString()
ask type.T.type to provide type display. |
protected void |
asString(StringBuffer buf)
compose type display. |
List |
body()
returns the second descendant, the procedure body. |
boolean |
equals(Object o)
type equality: two type.ProcT with equal result type
and equal parameter types. |
String |
name()
returns the first descendant, the procedure name. |
String[] |
names()
|
type.T[] |
params()
|
protected void |
params(StringBuffer buf)
append parameter type list, if any. |
protected void |
primitive(StringBuffer buf)
append primitive result type. |
type.T |
result()
|
String |
toPrefix()
returns type-specific prefix. |
| Methods inherited from class step10.type.T |
|---|
type |
| Methods inherited from class java.util.ArrayList |
|---|
add, add, addAll, addAll, clear, clone, contains, ensureCapacity, get, indexOf, isEmpty, lastIndexOf, remove, remove, removeRange, set, size, toArray, toArray, trimToSize |
| Methods inherited from class java.util.AbstractList |
|---|
hashCode, iterator, listIterator, listIterator, subList |
| Methods inherited from class java.util.AbstractCollection |
|---|
containsAll, removeAll, retainAll, toString |
| Methods inherited from class java.lang.Object |
|---|
finalize, getClass, notify, notifyAll, wait, wait, wait |
| Methods inherited from interface java.util.List |
|---|
containsAll, hashCode, iterator, listIterator, listIterator, removeAll, retainAll, subList |
| Field Detail |
|---|
protected final type.T result
protected final type.T[] params
protected final String[] names
| Constructor Detail |
|---|
protected type.ProcT(type.T result,
type.T[] params)
protected type.ProcT(type.T result,
String name,
type.T[] params,
String[] names,
List body)
protected type.ProcT(Object type,
List sub)
| Method Detail |
|---|
public type.T result()
public type.T[] params()
public String[] names()
public String name()
public List body()
public String toPrefix()
type.T
toPrefix in class type.Tpublic boolean equals(Object o)
type.ProcT with equal result type
and equal parameter types.
equals in interface Collectionequals in interface Listequals in class AbstractListpublic String asString()
type.T.type to provide type display.
asString in class type.Tprotected void asString(StringBuffer buf)
protected void primitive(StringBuffer buf)
protected void params(StringBuffer buf)
|
|||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | ||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | ||||||||